<?php
/**
 * Welcome Screen Class
 * Sets up the welcome screen page, hides the menu item
 * and contains the screen content.
 */
class DGWorkAdmin {

	/**
	 * Constructor
	 * Sets up the welcome screen
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'admin_register_menu' ) );
		add_action( 'load-themes.php', array( $this, 'activation' ) );
		add_action( 'load-themes.php', array( $this, 'admin_notice' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_style' ) );
		add_action( 'admin_init', array($this,'register_option_setting'));
		add_action( 'admin_init', array($this,'plugin_action'));
		add_action( 'DGWorkAdmin_header', array( $this, 'admin_ui_header' ), 10 );
		add_action( 'demo_importer_header', array( $this, 'admin_ui_header' ), 10);
		add_filter( 'pt-ocdi/plugin_page_setup', array($this, 'demo_import_menu'));
		add_filter( 'pt-ocdi/plugin_page_title', array($this,'remove_demo_page_title'));
		add_action( 'demo_importer_before', array($this, 'no_registered_info_on_demo_page'));
		add_action( 'wp_dashboard_setup', array($this,'add_dashboard_widgets') );
	} // end constructor
     

	/**
	 * Adds an admin notice upon successful activation.
	 * @since 1.0.0
	 */
	public function activation() {
		global $pagenow, $dgwork_theme;

		if ( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) { 
			wp_redirect(admin_url("themes.php?page=introduction")); 
		}

		if(get_option('dgwork_version') !== null){
		   update_option('dgwork_version', $dgwork_theme['Version']);
		}else{
		   add_option('dgwork_version', $dgwork_theme['Version']);
	    }
	}

	/**
	 * Display an admin notice linking to the welcome screen
	 * @since 1.0.0
	 */
	public function admin_notice() {
		if( !DGWorkAdmin::check_license()) {
		?>
			<div class="updated error is-dismissible">
				<p><?php echo sprintf( esc_html__( 'Thanks for choosing DGWork Theme! Please register your purchase code to activate auto theme update.', 'dgwork')); ?></p>
				<p><a href="<?php echo esc_url( admin_url( 'themes.php?page=registration' ) ); ?>" class="button" style="text-decoration: none;"><?php _e( 'Register Now', 'dgwork' ); ?></a></p>
			</div>
		<?php
	    }
	}

	/**
	 * Load admin screen css
	 * @return void
	 * @since  1.0.0
	 */
	public function admin_style( $hook_suffix ) {
			wp_enqueue_style( 'dgwork-dashboard', DGWORK_INC_URI. 'admin/css/dashboard.css','');
			wp_enqueue_style( 'thickbox' );
			wp_enqueue_script( 'thickbox' );
	}

	/**
	 * Creates the dashboard page
	 * @see  add_theme_page()
	 * @since 1.1.5
	 */
	public function admin_register_menu() {
		if(current_user_can('edit_theme_options')){
			$plugins_callback = array( $this, 'ui_plugins' );
			if ( isset( $_GET['tgmpa-install'] ) || isset( $_GET['tgmpa-update'] ) ) {
				require_once  DGWORK_INC_DIR.'admin/class-tgm-plugin-activation.php';
				remove_action( 'admin_notices', array( $GLOBALS['tgmpa'], 'notices' ) );
				$plugins_callback = array( $GLOBALS['tgmpa'], 'install_plugins_page' );
			}
            
            add_theme_page('Introduction', 'Introduction', 'edit_theme_options', 'introduction', array( $this, 'ui_intro' ));
			add_theme_page('Registration', 'Registration', 'edit_theme_options', 'registration', array( $this, 'ui_registration' ));
			add_theme_page('Plugins', 'Plugins', 'install_plugins', 'plugins', $plugins_callback);
			add_theme_page('Support', 'Support', 'edit_theme_options', 'support', array( $this, 'ui_support' ));
			add_theme_page('Resources', 'Resources', 'edit_theme_options', 'resources', array( $this, 'ui_resources' ));
			
	    }
	}

	/**
	 * Demo Importer Menu
	 * @since 1.1.5
	 */
	public function demo_import_menu( $default_settings ) {
		$default_settings['parent_slug'] = 'themes.php';
		$default_settings['page_title']  = esc_html__( 'DGWork Demos' , 'dgwork' );
		$default_settings['menu_title']  = esc_html__( 'Import Demo' , 'dgwork' );
		$default_settings['capability']  = 'import';
		$default_settings['menu_slug']   = 'dgwork-demos';

		return $default_settings;
	}

	/**
	 * Remove Demo Page Title
	 */
	public function remove_demo_page_title(){
		return '';
	}

	public function no_registered_info_on_demo_page(){
		return true;
		if( !DGWorkAdmin::check_license()) {
			echo '<div class="box" style="border-left: 4px solid #dc3232;">'.esc_html__('Purchase Code is required before you import the demo data, please add a valid purchase code in Registration page.','dgwork').'</div>';
			die();
		}
	}

	/**
	 * The Admin screen header
	 * @since 1.0.0
	 */
	public function admin_ui_header() {
		global $dgwork_theme;
		?>
		<div class="wrap about-wrap dgwork-wrap">
			<h1><?php echo '<strong>'.esc_attr($dgwork_theme['Name']).'</strong> <sup class="version">' . esc_attr( $dgwork_theme['Version'] ) . '</sup>'; ?></h1>
			<p class="intro"><?php echo esc_attr($dgwork_theme['Description']); ?></p>

		    <?php
			  $active_tab = '';
			  if( isset( $_GET[ 'page' ] ) ) {
			      $active_tab = $_GET[ 'page' ];
			  }
		    ?>
		    <h2 class="nav-tab-wrapper">

		    	<?php do_action('dgwork_before_admin_tabs');?>

		    	<a href="<?php echo admin_url('themes.php?page=introduction');?>" class="<?php echo $active_tab == 'introduction' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Introduction', 'dgwork');?></a>
				<a href="<?php echo admin_url('themes.php?page=registration');?>" class="<?php echo $active_tab == 'registration' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Registration', 'dgwork');?></a>
				<a href="<?php echo admin_url('themes.php?page=plugins');?>" class="<?php echo $active_tab == 'plugins' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Plugins', 'dgwork');?></a>
				<?php if(class_exists('ThemeVan_Toolkit')):?>
				<a href="<?php echo admin_url('themes.php?page=dgwork-demos');?>" class="<?php echo $active_tab == 'dgwork-demos' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Demos', 'dgwork');?></a>
			    <?php endif;?>
			    <a href="<?php echo admin_url('themes.php?page=resources');?>" class="<?php echo $active_tab == 'resources' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Resources', 'dgwork');?></a>
				<a href="<?php echo admin_url('themes.php?page=support');?>" class="<?php echo $active_tab == 'support' ? 'nav-tab-active' : ''; ?> nav-tab"><?php esc_html_e('Support', 'dgwork');?></a>

				<?php do_action('dgwork_after_admin_tabs');?>
			</h2>
		<?php
	}

	/**
	 * Admin screen UI
	 * @since 1.0.0
	 */
	public function ui_intro(){
	   require_once( get_template_directory() . '/inc/admin/ui/intro.php' );
	}
    public function ui_registration(){
	   require_once( get_template_directory() . '/inc/admin/ui/registration.php' );
    }
    public function ui_plugins(){
	   require_once( get_template_directory() . '/inc/admin/ui/plugins.php' );
    }
    public function ui_support(){
	   require_once( get_template_directory() . '/inc/admin/ui/support.php' );
    }
    public function ui_resources(){
	   require_once( get_template_directory() . '/inc/admin/ui/resources.php' );
    }

    /** 
     * Check license key
     * @since 1.0.0 
     */
	public static function check_license(){
     	$license = get_option('purchase_key');
		if($license <> '' && isset($license)){
			return true;
		}else{
			return false;
		}
	}

	/* check license */
	public static function activate_license($license_key) {
		$request = wp_remote_get(THEMEVAN_API.'envato_verifier.php?purchase_key='.$license_key.'&item_id='.DGWORK_ITEM_ID);
	    if( is_wp_error( $request ) ) {
	      return false; // Bail early
	    }
	    $oauth_api = wp_remote_retrieve_body( $request );
	    $oauth = json_decode($oauth_api,TRUE);
		$status = $oauth['status'];

		if( $status == 'activated') {
			update_option('purchase_key', $license_key);
			update_option('expired_date', $oauth['supported_until']);
			return true;
			exit;
			// this license is still valid
		} else {
			echo '<script>jQuery(document).ready(function($){$("#no-activated").show();});</script>';
			self::deactivate_license();
			return false;
			exit;
			// this license is no longer valid
		}
	}

	/** 
     * Dectivate license key
     * @since 1.0.3
     */
	public static function deactivate_license(){
		update_option('purchase_key', '');
		update_option('expired_date', '');
	}

	/**
	 * Check license Expired
	 * @since 1.2.5
	 */
	public static function is_expired(){
		if(date("Y-m-d h:i:sa") >= date("Y-m-d h:i:sa",strtotime(get_option('expired_date')))){
             return true;
        }else{
        	 return false;
        }
        return true;
	}

	/**
	 * Register Option Setting
	 * @since 1.0.0
	 */
	public function register_option_setting() {
	   register_setting( 'dgwork_option_group', 'purchase_key', ''); 
	   register_setting( 'dgwork_option_group', 'expired_date', ''); 
    } 
    

    /**
     * Text Field
     */
	public static function text($name,$val,$readonly) {
	  if(null !== get_option($name) && get_option($name)<>''){
	  	 $val = get_option($name);
	  }
	  $readonly_prop = '';
	  if($readonly==true){
	  	 $readonly_prop = 'readonly';
	  }
	  $return_html = '<input name="'.$name.'" type="text" class="ui textfield" value="'.$val.'" '.$readonly_prop.'>';      
      return $return_html;
	}

	/**
     * Hidden Field
     */
	public static function hidden($name,$val) {
	  if(null !== get_option($name) && get_option($name)<>''){
	  	 $val = get_option($name);
	  }
	  $return_html = '<input name="'.$name.'" type="hidden" class="ui textfield" value="'.$val.'">';      
      return $return_html;
	}
   
    /**
     * Add Dashboard Widget
     */
    public function add_dashboard_widgets() {
        wp_add_dashboard_widget('dashboard_widget', 'ThemeVan News', array($this, 'dashboard_widget')); 
    }

    public function dashboard_widget() {
	    echo '<div class="themevan-news-widget rss-widget">';
		wp_widget_rss_output(array(
		'url' => 'https://www.themevan.com/category/themevan-news/feed',
		'items' => 5,
		'show_summary' => 0,
		'show_author' => 0,
		'show_date' => 1
		));
		echo "</div>";
    }

	/**
	 * Get the plugin link.
	 *
	 * @access  public
	 * @param array $item The plugin in question.
	 * @return  array
	 */
	public static function plugin_link( $item ) {
		$installed_plugins = get_plugins();

		$item['sanitized_plugin'] = $item['name'];

		$actions = array();

		// We have a repo plugin.
		if ( ! $item['version'] ) {
			$item['version'] = TGM_Plugin_Activation::$instance->does_plugin_have_update( $item['slug'] );
		}

		$disable_class = '';
		$data_version  = '';

		if ( 'revslider' == $item['slug'] || 'js_composer' == $item['slug'] || 'themevan_toolkit' == $item['slug']){
			if(!DGWorkAdmin::check_license()){
				$disable_class = '';
			}
		}

		// We need to display the 'Install' hover link.
		if ( ! isset( $installed_plugins[ $item['file_path'] ] ) ) {
			if ( ! $disable_class ) {
				$url = esc_url( wp_nonce_url(
					add_query_arg(
						array(
							'page'          => rawurlencode( TGM_Plugin_Activation::$instance->menu ),
							'plugin'        => rawurlencode( $item['slug'] ),
							'plugin_name'   => rawurlencode( $item['sanitized_plugin'] ),
							'tgmpa-install' => 'install-plugin',
							'return_url'    => 'dgwork_plugins',
						),
						TGM_Plugin_Activation::$instance->get_tgmpa_url()
					),
					'tgmpa-install',
					'tgmpa-nonce'
				) );
			} else {
				$url = '#';
			}
			$actions = array(
				'install' => '<a href="' . $url . '" class="button button-primary' . $disable_class . '"' . $data_version . ' title="' . sprintf( esc_attr__( 'Install %s', 'dgwork' ), $item['sanitized_plugin'] ) . '">' . esc_attr__( 'Install', 'dgwork' ) . '</a>',
			);
		} elseif ( is_plugin_inactive( $item['file_path'] ) ) {
			// We need to display the 'Activate' hover link.
			$url = esc_url( add_query_arg(
				array(
					'plugin'               => rawurlencode( $item['slug'] ),
					'plugin_name'          => rawurlencode( $item['sanitized_plugin'] ),
					'dgwork-activate'       => 'activate-plugin',
					'dgwork-activate-nonce' => wp_create_nonce( 'dgwork-activate' ),
				),
				admin_url( 'themes.php?page=plugins' )
			) );

			$actions = array(
				'activate' => '<a href="' . $url . '" class="button button-primary"' . $data_version . ' title="' . sprintf( esc_attr__( 'Activate %s', 'dgwork' ), $item['sanitized_plugin'] ) . '">' . esc_attr__( 'Activate' , 'dgwork' ) . '</a>',
			);
		} elseif ( version_compare( $installed_plugins[ $item['file_path'] ]['Version'], $item['version'], '<' ) ) {
			$disable_class = '';
			// We need to display the 'Update' hover link.
			$url = wp_nonce_url(
				add_query_arg(
					array(
						'page'          => rawurlencode( TGM_Plugin_Activation::$instance->menu ),
						'plugin'        => rawurlencode( $item['slug'] ),
						'tgmpa-update'  => 'update-plugin',
						'version'       => rawurlencode( $item['version'] ),
						'return_url'    => 'dgwork_plugins',
					),
					TGM_Plugin_Activation::$instance->get_tgmpa_url()
				),
				'tgmpa-update',
				'tgmpa-nonce'
			);
			if ('revslider' == $item['slug'] || 'js_composer' == $item['slug'] || 'themevan_shortcodes' == $item['slug']){
				if(!DGWorkAdmin::check_license()){
				   $disable_class = ' disabled';
			    }
			}
			$actions = array(
				'update' => '<a href="' . $url . '" class="button button-primary' . $disable_class . '" title="' . sprintf( esc_attr__( 'Update %s', 'dgwork' ), $item['sanitized_plugin'] ) . '">' . esc_attr__( 'Update', 'dgwork' ) . '</a>',
			);
		} elseif ( is_plugin_active( $item['file_path'] ) ) {
			$url = esc_url( add_query_arg(
				array(
					'plugin'                 => rawurlencode( $item['slug'] ),
					'plugin_name'            => rawurlencode( $item['sanitized_plugin'] ),
					'dgwork-deactivate'       => 'deactivate-plugin',
					'dgwork-deactivate-nonce' => wp_create_nonce( 'dgwork-deactivate' ),
				),
				admin_url( 'themes.php?page=plugins' )
			) );
			$actions = array(
				'deactivate' => '<a href="' . $url . '" class="button button-primary" title="' . sprintf( esc_attr__( 'Deactivate %s', 'dgwork' ), $item['sanitized_plugin'] ) . '">' . esc_attr__( 'Deactivate', 'dgwork' ) . '</a>',
			);
		} // End if.

		return $actions;
	}

	/**
	 * Actions to run on initial theme activation.
	 */
	public function plugin_action() {

		if ( current_user_can( 'edit_theme_options' ) ) {

			if ( isset( $_GET['dgwork-deactivate'] ) && 'deactivate-plugin' === $_GET['dgwork-deactivate'] ) {
				check_admin_referer( 'dgwork-deactivate', 'dgwork-deactivate-nonce' );

				$plugins = TGM_Plugin_Activation::$instance->plugins;

				foreach ( $plugins as $plugin ) {
					if ( isset( $_GET['plugin'] ) && $plugin['slug'] == $_GET['plugin'] ) {
						deactivate_plugins( $plugin['file_path'] );
					}
				}
			}
			if ( isset( $_GET['dgwork-activate'] ) && 'activate-plugin' === $_GET['dgwork-activate'] ) {
				check_admin_referer( 'dgwork-activate', 'dgwork-activate-nonce' );

				$plugins = TGM_Plugin_Activation::$instance->plugins;

				foreach ( $plugins as $plugin ) {
					if ( isset( $_GET['plugin'] ) && $plugin['slug'] == $_GET['plugin'] ) {
						activate_plugin( $plugin['file_path'] );
						wp_safe_redirect( admin_url( 'themes.php?page=plugins' ) );
						exit;
					}
				}
			}
		}
	}

	

}

$GLOBALS['DGWorkAdmin'] = new DGWorkAdmin();