<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'dgwork_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @package  DGWork
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */


/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object
 *
 * @return bool             True if metabox should show
 */
if ( ! function_exists( 'dgwork_show_if_front_page' ) ) :
function dgwork_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template
	if ( $cmb->object_id !== get_option( 'page_on_front' ) ) {
		return false;
	}
	return true;
}
endif;

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object
 *
 * @return bool                     True if metabox should show
 */
if ( ! function_exists( 'dgwork_hide_if_no_cats' ) ) :
function dgwork_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}
endif;

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array             $field_args Array of field parameters
 * @param  CMB2_Field object $field      Field object
 */
if ( ! function_exists( 'dgwork_before_row_if_2' ) ) :
function dgwork_before_row_if_2( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}
endif;

/**
 * Get the Wordpress Menu
 */
if ( ! function_exists( 'dgwork_get_menus' ) ) :
function dgwork_get_menus(){
    $menus = get_terms('nav_menu');
    $menu_options = array('Default Menu');
	foreach($menus as $menu){
	  $menu_options[$menu->slug] = $menu->name;
	} 
	return $menu_options;
}
endif;

/**
 * Hook in and add a details metabox.
 * Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
add_action( 'cmb2_admin_init', 'dgwork_register_details_metabox' );
if ( ! function_exists( 'dgwork_register_details_metabox' ) ) :
function dgwork_register_details_metabox() {

  // Start with an underscore to hide fields from custom fields list
  $prefix = '_dgwork_';

  /**
   * Post settings
   */
  $cmb_dgwork_post = new_cmb2_box( array(
	'id'            => $prefix . 'post_metabox',
	'title'         => esc_html__( 'DGWork Post Settings', 'dgwork' ),
	'object_types'  => array( 'post'), // Post type
	'priority'   => 'high',
	'context'    => 'normal',
  ) );

  $cmb_dgwork_post->add_field( array(
		'name'             => esc_html__( 'Post Template', 'dgwork' ),
		'desc'             => esc_html__( 'Specify a template for this post.', 'dgwork' ),
		'id'               => $prefix . 'post_template',
		'type'             => 'select',
		'default'		   => '1',
		'options'		   => array('0'=>'Right Sidebar','1'=>'No Sidebar')
  ) );

  /**
   * Page settings
   */
  $cmb_dgwork_page = new_cmb2_box( array(
	'id'            => $prefix . 'page_metabox',
	'title'         => esc_html__( 'DGWork Page Settings', 'dgwork' ),
	'object_types'  => array( 'page', 'post', 'download' ), // Post type
	'priority'   => 'default',
	'tabs'       => apply_filters('dgwork_page_setting_tabs',
		array(
			'page_navi' => array(
				'label'   => __( 'Page Navigation Bar', 'dgwork' ),
			),
			'page_header' => array(
				'label'   => __( 'Page Header', 'dgwork' ),
			),
			'misc' => array(
				'label'   => __( 'Misc', 'dgwork' ),
			)
		)
	),
	'tab_style'  => 'default',
  ) );
  
  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Navigation Bar: Transparent Background', 'dgwork' ),
		'desc'             => esc_html__( 'Remove the background color of navigation bar', 'dgwork' ),
		'id'               => $prefix . 'transparent_nav',
		'type'             => 'switch',
		'default'		   => '0',
		'tab' 			   => 'page_navi',
		'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Navigation Bar: Background Color', 'dgwork' ),
		'desc'             => esc_html__( 'Set the menu link color for this page separately.', 'dgwork' ),
		'id'               => $prefix . 'navbar_color',
		'type'             => 'colorpicker',
		'default'		   => '#fff',
		'tab' 			   => 'page_navi',
		'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Navigation Bar: Link Color', 'dgwork' ),
		'desc'             => esc_html__( 'Set the menu link color for this page separately.', 'dgwork' ),
		'id'               => $prefix . 'menu_text_color',
		'type'             => 'colorpicker',
		'default'		   => '#000',
		'tab' 			   => 'page_navi',
		'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Custom LOGO', 'dgwork' ),
		'desc'             => esc_html__( 'The page custom LOGO will replace the default LOGO in this page. The recommended size of LOGO is 280x60px', 'dgwork' ),
		'id'               => $prefix . 'logo',
		'type'             => 'file',
	    'options' => array(
	        'url' => true, // Hide the text input for the url
	    ),
	    'text'    => array(
	        'add_upload_file_text' => esc_html__('Upload Custom LOGO','dgwork') // Change upload button text. Default: "Add or Upload File"
	    ),
	    'tab' 			   => 'page_navi',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Top Menu For This Page', 'dgwork' ),
		'desc'             => esc_html__( 'This menu will instead of the default top menu.', 'dgwork' ),
		'id'               => $prefix.'page_menu',
		'type'             => 'select',
		'options_cb'       => 'dgwork_get_menus',
		'tab' 			   => 'page_navi',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );


  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Background', 'dgwork' ),
		'desc'             => esc_html__( 'The picture will display as the page header background.', 'dgwork' ),
		'id'               => $prefix . 'page_header_background',
		'type'             => 'file',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Background Color', 'dgwork' ),
		'id'               => $prefix . 'page_header_background_color',
		'type'             => 'colorpicker',
		'default'		   => '#333333',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
   ) );

   $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Text Color', 'dgwork' ),
		'desc'             => esc_html__( 'Set the text color for the page heading and subtitle.', 'dgwork' ),
		'id'               => $prefix . 'page_header_text_color',
		'type'             => 'colorpicker',
		'default'		   => '#fff',
		'tab' 			   => 'page_header',
		'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Remove Page Header Overlay', 'dgwork' ),
		'id'               => $prefix . 'page_header_overlay',
		'type'             => 'select',
		'default'		   => '0',
		'options'          => array(
			'0'  => esc_html__('No', 'dgwork'),
			'1'  => esc_html__('Yes','dgwork')
		),
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Tagline', 'dgwork' ),
		'desc'             => esc_html__( 'It shown below the page title.', 'dgwork' ),
		'id'               => $prefix . 'page_header_tagline',
		'type'             => 'text',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Title Size', 'dgwork' ),
		'desc'             => esc_html__( 'The font size of this page title. You can use px/em/rem unit.', 'dgwork' ),
		'id'               => $prefix . 'page_header_title_size',
		'default'		   => '40px',
		'type'             => 'text',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Title Line Height', 'dgwork' ),
		'desc'             => esc_html__( 'The line height of this page title. You can use px/em/rem unit.', 'dgwork' ),
		'id'               => $prefix . 'page_header_title_line_height',
		'default'		   => '1.2em',
		'type'             => 'text',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Text Alignment', 'dgwork' ),
		'id'               => $prefix.'page_header_text_aligned',
		'type'             => 'select',
		'desc'             => '<a id="header_alignment"></a>',
		'options'        =>  array(
			'left' => esc_html__('Left','dgwork'),
			'center' => esc_html__('Center','dgwork'),
			'right' => esc_html__('Right','dgwork')
		),
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Page Header: Slider', 'dgwork' ),
		'desc'             => esc_html__( 'Please add the Slider Revolution shortcode here, the same to LayerSlider.', 'dgwork' ),
		'id'               => $prefix . 'page_header_slider',
		'type'             => 'text',
		'tab' 			   => 'page_header',
	    'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );

  $cmb_dgwork_page->add_field( array(
		'name'             => esc_html__( 'Side Bullets Link', 'dgwork' ),
		'desc'             => esc_html__( 'Add the row id above and separate them by English comma, e.g. #about,#service,#contact', 'dgwork' ),
		'id'               => $prefix . 'bullets_link',
		'type'             => 'text',
		'tab' 			   => 'misc',
		'render_row_cb'	   => array('CMB2_Tabs', 'tabs_render_row_cb'),
  ) );
}
endif;

/**
 * Hook in and add a product metabox.
 * Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
add_action( 'cmb2_admin_init', 'dgwork_register_product_metabox' );
if ( ! function_exists( 'dgwork_register_product_metabox' ) ) :
function dgwork_register_product_metabox() {
	$prefix = '_dgwork_';
	
	if ( class_exists( 'Easy_Digital_Downloads' ) ){
	/**
	 * Product Item settings
	 */
	$cmb_dgwork = new_cmb2_box( array(
		'id'            => $prefix . '_details_metabox',
		'title'         => esc_html__( 'Item Details', 'dgwork' ),
		'object_types'  => array( 'download'), // Post type
		// 'show_on_cb' => 'dgwork_show_if_front_page', // function should return a bool value
		 'context'    => 'normal',
		 'priority'   => 'high',
		 'show_names' => true, // Show field names on the left
		// 'cmb_styles' => false, // false to disable the CMB stylesheet
		// 'closed'     => true, // true to keep the metabox closed by default
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Short Description', 'dgwork' ),
		'desc'             => esc_html__( 'It will shown on both product archive page and single product page, underneath the product title. Maximum 100 characters.', 'dgwork' ),
		'id'               => $prefix . 'short_description',
		'type'             => 'textarea_small'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Preview Type', 'dgwork' ),
		'desc'             => esc_html__( 'Choose a type for the preview mode', 'dgwork' ),
		'id'               => $prefix . 'preview_type',
		'type'             => 'select',
		'default'		   => 'featured',
		'options'          => array(
			'featured' => 'Use Featured Image',
			'pictures' => 'Pictures',
			'audio'   => 'Audio',
			'video'     => 'Youtube/Vimeo Video',
			'video_file'     => 'Link to Video File'
		),
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Preview Pictures', 'dgwork' ),
		'desc'             => esc_html__( 'The pictures will display as slideshow', 'dgwork' ),
		'id'               => $prefix . 'preview_pictures',
		'type'             => 'file_list'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Preview Video', 'dgwork' ),
		'desc'             => esc_html__( 'Add Youtube/Vimeo Video link if you host the video on Youtube/Vimeo.', 'dgwork' ),
		'id'               => $prefix . 'preview_video',
		'type'             => 'text_url'
	) );

	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Video File URL', 'dgwork' ),
		'desc'             => esc_html__( 'Add video file URL to here if you upload the video to your server or external server. Support video format are mp4 and webm.', 'dgwork' ),
		'id'               => $prefix . 'video_url',
		'type'             => 'text_url'
	) );
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Disable Built-in Player', 'dgwork' ),
		'desc'             => esc_html__( 'The theme built-in player will be disabled, instead, it will show the Vimeo or Youtube default player.', 'dgwork' ),
		'id'               => $prefix . 'disable_theme_player',
		'type'             => 'select',
		'default'		   => '0',
		'options'          => array(
			'0' => 'No',
			'1' => 'Yes',
		),
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Preview Audio', 'dgwork' ),
		'desc'             => esc_html__( 'Please upload mp3 audio file', 'dgwork' ),
		'id'               => $prefix . 'preview_audio',
		'type'             => 'file'
	) );
		
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'External Preview URL', 'dgwork' ),
		'desc'             => esc_html__( 'If you set the external preview URL here, a preview button will display underneath the buy button.', 'dgwork' ),
		'id'               => $prefix . 'preview_url',
		'type'             => 'text_url'
	) );

	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'External Checkout/Download URL', 'dgwork' ),
		'desc'             => esc_html__( 'Add the external checkout or file download link here, after click the buy button, it will open the external page.', 'dgwork' ),
		'id'               => $prefix . 'external_checkout_url',
		'type'             => 'text'
	) );

	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Hide Price', 'dgwork' ),
		'desc'             => esc_html__( 'Hide the price on single product and archive page.', 'dgwork' ),
		'id'               => $prefix . 'hide_price',
		'type'             => 'select',
		'default'		   => '0',
		'options'          => array(
			'0' => 'No',
			'1' => 'Yes',
		),
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Hide Free Text', 'dgwork' ),
		'desc'             => esc_html__( 'Hide the free text on archive page.', 'dgwork' ),
		'id'               => $prefix . 'hide_free',
		'type'             => 'select',
		'default'		   => '0',
		'options'          => array(
			'0' => 'No',
			'1' => 'Yes',
		),
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'File Type', 'dgwork' ),
		'desc'             => esc_html__( 'ex. jpg, php, css', 'dgwork' ),
		'id'               => $prefix . 'custom_file_type',
		'type'             => 'text'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'File Size', 'dgwork' ),
		'desc'             => esc_html__( 'ex. 10M or 10K', 'dgwork' ),
		'id'               => $prefix . 'file_size',
		'type'             => 'text'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Last Updated Date', 'dgwork' ),
		'desc'             => esc_html__( 'ex. March 29, 2016', 'dgwork' ),
		'id'               => $prefix . 'last_updated_date',
		'type'             => 'text'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Requirements', 'dgwork' ),
		'desc'             => esc_html__( 'Add the requirement software here. ex. Adobe Photoshop CS6, WordPress', 'dgwork' ),
		'id'               => $prefix . 'requirements',
		'type'             => 'text'
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Licenses', 'dgwork' ),
		'desc'             => esc_html__( 'Choose the license type for your item.', 'dgwork' ),
		'id'               => $prefix . 'license',
		'type'             => 'radio_inline',
		'options'          => apply_filters('dgwork_preset_license',array(
			'noCopyright' => esc_html__('No Copyright','dgwork'),
			'GPL2' => 'GPL V2',
			'GPL3' => 'GPL V3',
			'MIT'   => 'MIT',
			'BSD'     => 'BSD',
			'Apache License'     => 'Apache License',
			'cc'     => 'Creative Commons License '
		)),
	) );
	
	$custom_license_group = $cmb_dgwork->add_field( array(
    'id'          => $prefix . 'license_info',
    'type'        => 'group',
    'description' => esc_html__( 'Define your own license type to instead of the preset licenses above', 'dgwork' ),
    'options'     => array(
        'group_title'   => esc_html__( 'Custom License {#}', 'dgwork' ), // since version 1.1.4, {#} gets replaced by row number
        'add_button'    => esc_html__( 'Add Another License', 'dgwork' ),
        'remove_button' => esc_html__( 'Remove dgwork', 'dgwork' ),
        'sortable'      => true, // beta
    ),
    ) );
    
    $cmb_dgwork->add_group_field( $custom_license_group, array(
		'name'             => esc_html__( 'License Name', 'dgwork' ),
		'desc'             => esc_html__( 'Define your own license name here.', 'dgwork' ),
		'id'               => $prefix . 'custom_license_name',
		'type'             => 'text',
	) );
	$cmb_dgwork->add_group_field( $custom_license_group, array(
		'name'             => esc_html__( 'License Description Link', 'dgwork' ),
		'desc'             => esc_html__( 'Link to the license description page. Don\'t miss http://', 'dgwork' ),
		'id'               => $prefix . 'custom_license_link',
		'type'             => 'text_url',
	) );
	
	$cmb_dgwork->add_field( array(
		'name'             => esc_html__( 'Additional Details', 'dgwork' ),
		'desc'             => esc_html__( 'You can add your own details list in &lt;dd&gt;&lt;/dd&gt; tag. You can also insert the fontawesome icon as &lt;i class="fa fa-ICON-NAME"&gt;&lt;/i&gt;', 'dgwork' ),
		'id'               => $prefix . 'additional_details',
		'type'             => 'textarea'
	) );
	

	/**
	 * product template settings
	 */
	$cmb_dgwork_product_template = new_cmb2_box( array(
		'id'            => $prefix . '_product_template_metabox',
		'title'         => esc_html__( 'Product Template', 'dgwork' ),
		'object_types'  => array( 'download'), // Post type
		'context'    => 'side',
		'priority'   => 'default',
		'show_names' => true, // Show field names on the left
	) );

	$cmb_dgwork_product_template->add_field( array(
		'name'             => esc_html__( 'Product Template', 'dgwork' ),
		'desc'             => __( 'Specify a template for this product, and you can also set the header content alignment via Common <a href="#header_alignment" id="hightlight_header_alignment">Custom Page Settings section > Header Content Alignment</a>', 'dgwork' ),
		'id'               => $prefix . 'product_template',
		'type'             => 'select',
		'default'		   => '0',
		'options'		   => array(
			'0'=>'Standard Template',
			'1'=>'Custom Template',
			'2'=>'Custom Template with Sidebar',
			'3'=>'Minimal Template',
			'4'=>'Blank Template',
		)
  	) );

	$cmb_dgwork_product_template->add_field( array(
		'name'             => esc_html__( 'Product Header Subtitle', 'dgwork' ),
		'desc'             => esc_html__( 'It will shown underneath the product title and replace the short description separately for the single product page. Maximum 300 characters.', 'dgwork' ),
		'id'               => $prefix . 'product_header_subtitle',
		'type'             => 'textarea',
	) );

	 $cmb_dgwork_product_template ->add_field( array(
		'name'             => esc_html__( 'Product Header Background', 'dgwork' ),
		'desc'             => esc_html__( 'The picture will shown as the post header background.', 'dgwork' ),
		'id'               => $prefix . 'header_background',
		'type'             => 'file'
	) );

  }
}
endif;