<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "dgwork_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'dgwork_option',
        'display_name' => 'DGWork Options',
        'display_version' => FALSE,
        'page_slug' => 'dgwork_options',
        'page_title' => 'DGWork Options',
        'update_notice' => FALSE,
        'forced_dev_mode_off' => true,
        'dev_mode'  => FALSE,
        'intro_text' => '<p>You can manage the settings of site with the following options</p>',
        'footer_text' => '<p>If you have any questions, please go to <a href="https://forum.themevan.com/?utm_source=dgwork_opt&utm_medium=footer" target="_blank">ThemeVan Support Forum</a>. You can also visit our <a href="https://www.themevan.com/?utm_source=dgwork_opt&utm_medium=footer" target="_blank">official site</a>.</p>',
        'admin_bar' => TRUE,
        'menu_type' => 'submenu',
        'menu_title' => 'Theme Options',
        'allow_sub_menu' => TRUE,
        'page_parent' => 'themes.php',
        'page_parent_post_type' => 'your_post_type',
        'page_priority' => '30',
        'customizer' => TRUE,
        'class' => 'dgwork_options',
        'hints' => array(
            'icon' => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color' => '#bfbfbf',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'dark',
                'shadow' => '1',
                'rounded' => '1',
                'style' => 'bootstrap',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'effect' => 'slide',
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'effect' => 'fade',
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => esc_url('https://github.com/themevan'),
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => esc_url('https://www.facebook.com/themevan'),
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => esc_url('http://twitter.com/themevan'),
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => esc_url('http://plus.google.com/+themevan'),
        'title' => 'Find us on Google+',
        'icon'  => 'el el-google-plus'
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'dgwork' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'dgwork' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'dgwork' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'dgwork' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( '<p>This is the sidebar content, HTML is allowed.</p>', 'dgwork' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // -> START Fields
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'dgwork' ),
        'id'               => 'general-settings',
        'desc'             => esc_html__( '', 'dgwork' ),
        'fields'           => array(
            array(
                'id'       => 'minify',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Use Minify CSS & JS File', 'dgwork' ),
                'desc'             => esc_html__( 'Use minify CSS and JS file can speed up the page loading speed. The minified CSS and JS file are located in the /wp-content/themes/dgwork/build/ folder, they will replace all script and stylesheet files which are included in the assets folder.', 'dgwork' ),
                'default'  => TRUE,
                'options' => array(
                                TRUE => 'Yes', 
                                FALSE => 'No'
                             ), 
            ),

            array(
                'id'       => 'breadcrumbs',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Enable Breadcrumbs Navigation', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),

           array(
                'id'       => 'search_text',
                'type'     => 'text',
                'title'    => esc_html__( 'Search Placeholder Text', 'dgwork' ),
                'default'  => 'Start typing and press Enter to search',
            ),

            array(
                'id'       => 'social_icons',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Social Share Icons', 'dgwork' ),
                'desc'             => esc_html__( 'The social share icons is displayed in the single post.', 'dgwork' ),
                'options'  => array(
                    'facebook' => 'Facebook',
                    'twitter' => 'Twitter',
                    'google-plus' => 'Google+',
                    'pinterest' => 'Pinterest',
                    'linkedin' => 'LinkedIn'
                ),
             
                //See how default has changed? you also don't need to specify opts that are 0.
                'default' => array(
                    'facebook' => 'Facebook',
                    'twitter' => 'Twitter',
                    'google-plus' => 'Google+',
                    'pinterest' => 'Pinterest',
                    'linkedin' => 'LinkedIn'
                )
            ),
        )
    ));


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header', 'dgwork' ),
        'id'               => 'header-settings',
        'fields'           => array(
            array(
                'id'       => 'header_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Header Layout', 'dgwork' ),
                'default'  => '1',
                'options' => array(
                                '1'  => array(
                                    'alt'   => 'Default Header', 
                                    'img'   => DGWORK_INC_URI.'admin/img/header/default.png'
                                ),
                                '2' => array(
                                    'alt'   => 'RTL Header', 
                                    'img'   => DGWORK_INC_URI.'admin/img/header/rtl.png'
                                ),
                                '3' => array(
                                    'alt'   => 'Centered LOGO Header', 
                                    'img'  => DGWORK_INC_URI.'admin/img/header/centered.png'
                                ),
                             ), 
            ),

           array(
                'id'       => 'sticky_top',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Sticky Header', 'dgwork' ),
                'desc'             => esc_html__( 'The sticky header will always stay at the top of page while scrolling the page.', 'dgwork' ),
                'default'  => '1',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
           ),

           array(
                'id'       => 'top_icons',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Show Top Icon Buttons', 'dgwork' ),
                'desc'             => esc_html__( 'You can show or get rid of the top icon buttons from the navigation bar.', 'dgwork' ),
                'default'  => '1',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            )
        )
    ));



    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Footer', 'dgwork' ),
        'id'               => 'footer-settings',
        'fields'           => array(
             array(
                'id'       => 'hide_default_footer',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Hide Default Bottom Section & Footer', 'dgwork' ),
                'desc'     => esc_html__( 'When you want to use content block to make a custom footer, you could hide the default footer.', 'dgwork' ),
                'default'  => FALSE,
                'options'  => array(
                                TRUE => 'Yes', 
                                FALSE => 'No'
                             ), 
            ),

           array(
                'id'       => 'bottom_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Bottom Layout', 'dgwork' ),
                'desc'             => esc_html__( 'Select a layout for the bottom widget section.', 'dgwork' ),
                'default'  => '4',
                'options' => array(
                    '1/4+1/4+1/4+1/4'      => array(
                        'alt'   => '4 Columns', 
                        'img'   => DGWORK_INC_URI.'admin/img/columns/4.png'
                    ),
                    '1/3+1/3+1/3' => array(
                        'alt'   => '3 Columns', 
                        'img'   => DGWORK_INC_URI.'admin/img/columns/3.png'
                    ),
                    '1/2+1/2'      => array(
                        'alt'   => '2 Columns', 
                        'img'  => DGWORK_INC_URI.'admin/img/columns/2.png'
                    ),
                    '1/4+1/4+1/2'      => array(
                        'alt'   => '1/4+1/4+1/2', 
                        'img'   => DGWORK_INC_URI.'admin/img/columns/14+14+12.png'
                    ),
                    '1/6+1/6+2/3'      => array(
                        'alt'   => '1/6+1/6+2/3', 
                        'img'   => DGWORK_INC_URI.'admin/img/columns/16+16+23.png'
                    ),
                    '1/2+1/4+1/4'      => array(
                        'alt'  => '1/2+1/4+1/4', 
                        'img'  =>  DGWORK_INC_URI.'admin/img/columns/12+14+14.png'
                    ),
                    '2/3+1/6+1/6'      => array(
                        'alt'  => '2/3+1/6+1/6', 
                        'img'  => DGWORK_INC_URI.'admin/img/columns/23+16+16.png'
                    )
                ), 
            ),

            array(
                'id'       => 'copyright',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Copyright Text', 'dgwork' ),
                'mode' => 'html',
                'default'  => '',
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Shop', 'dgwork' ),
        'id'               => 'shop',
        'icon'             => 'el el-shopping-cart',
        'desc'             => esc_html__( 'The options for the EDD shop setup.', 'dgwork' ),
        'fields'           => array(
             array(
                'id'       => 'edd_slug',
                'type'     => 'text',
                'title'    => esc_html__('EDD Product Slug','dgwork'),
                'description'    => __( 'The default EDD product slug is "product", you can redefine the EDD product slug here. For example, if you change "product" to "book", then the link will be  <strong>http://domain.com/<em style="color:red">book</em>/this-is-product-title-or-id</strong>, after you changed EDD category Slug, please go to "Settings > Permalink" page, click the save button again.', 'dgwork' ),
                'default'  => 'product',
             ),

             array(
                'id'       => 'edd_category_slug',
                'type'     => 'text',
                'title'    => esc_html__('EDD Category Slug','dgwork'),
                'description'    => __( 'The default EDD category slug is "products", you can redefine the EDD category slug here. For example, if you change "products" to "product_category", then the link will be  <strong>http://domain.com/<em style="color:red">product_category</em>/this-is-category-name</strong>, after you changed EDD category Slug, please go to "Settings > Permalink" page, click the save button again.', 'dgwork' ),
                'default'  => 'products',
             ),

             array(
                'id'       => 'account_page',
                'type'     => 'select',
                'title'    => esc_html__( 'Select Account Page', 'dgwork' ),
                'default'  => 'Account',
                'data'     => 'page',
            ),

            array(
                'id'       => 'checkout_page',
                'type'     => 'select',
                'title'    => esc_html__( 'Select Checkout Page', 'dgwork' ),
                'default'  => 'Checkout',
                'data'     => 'page',
            ),

            array(
                'id'       => 'product_search',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Product Search Button', 'dgwork' ),
                'desc'             => esc_html__( 'You can enable/disable the product search button from the navigation bar.', 'dgwork' ),
                'default'  => '1',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),

            array(
                'id'       => 'product_comment',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Enable The Comments On The Product Page', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),


            array(
                'id'       => 'float_cart',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Float Cart Button', 'dgwork' ),
                'desc'             => esc_html__( 'The cart button will float on the right side of the window.', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),

            array(
                'id'       => 'hide_buy_now_button',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Hide The Buy Button in Archive Page & [downloads] Grid.', 'dgwork' ),
                'desc'     => esc_html__( 'When you hover on the product thumbnail in product archive page, you can hide the buy now button there.', 'dgwork' ),
                'default'  => '0',
                'options'  => array(
                                '1' => 'Yes',
                                '0' => 'No',
                              ), 
            ),


            array(
                'id'       => 'player_preview',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Show Player in The Archive Page', 'dgwork' ),
                'desc'             => esc_html__( 'If you enable this option, the player of the audio and video products will instead of the featured image in the products grid.', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Shop Notice', 'dgwork' ),
        'id'               => 'shop-notice-settings',
        'fields'           => array(
           array(
                'id'       => 'enable_shop_notice',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Enable Shop Notice', 'dgwork' ),
                'desc'             => esc_html__( 'If enable the shop notice, the text will be displayed in a extra top bar.', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
           ),

           array(
                'id'       => 'shop_notice',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Shop Notice Content', 'dgwork' ),
                'desc'     => esc_html__( 'HTML Supported.', 'dgwork' ),
                'default'  => '',
                'mode'     => 'html',
           ),

            array(
                'id'       => 'notice_bar_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Notice Bar Background Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#000',
                'output'   => array('background-color'=>'#dgw-notice-bar')
            ),

        )
    ));

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog', 'dgwork' ),
        'id'               => 'blog',
        'icon'             => 'el el-edit',
        'desc'             => esc_html__( 'Manage the sections for blog post page.', 'dgwork' ),
        'fields'           => array(
            array(
                'id'       => 'related_posts',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Related Posts', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),

            array(
                'id'       => 'single_related_posts_show_by',
                'type'     => 'select',
                'title'    => esc_html__( 'Related Posts Show By', 'dgwork' ),
                'default'  => '2',
                'options' => array(
                                '1' => 'Related Category', 
                                '2' => 'Related Tag'
                             ), 
            ),

            array(
                'id'       => 'post_author',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Post Author Section', 'dgwork' ),
                'default'  => '0',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),

            array(
                'id'       => 'single_post_thumbnail',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Show The Featured Image For Single Post?', 'dgwork' ),
                'default'  => '1',
                'options' => array(
                                '1' => 'Yes', 
                                '0' => 'No'
                             ), 
            ),
        )
    ));


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Colors', 'dgwork' ),
        'id'               => 'colors',
        'icon'             => 'el el-brush',
        'desc'             => esc_html__( 'Manage color scheme.', 'dgwork' ),
        'fields'           => array(
            array(
                'id'       => 'main_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Main Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#34b7ae',
                'output' => array('color' => 'a,#site-icons a:hover,.main-navigation a:hover,.widget li a:hover,.entry-title a:hover,.main-navigation ul li.current_page_item a,.main-navigation ul li.current-menu-item a,.main-navigation ul li.current-menu-parent a,#dgwork-buy .price span.free,#dgwork-buy .preview-demo,#edit-profile p.edd_password_change_notice,.account_content input[type="email"],#site-icons a:hover,.dgwork-products-grid li .dgwork-product-title a:hover,.post .entry-footer .author a,.pushy .account a,.tmvs-grid .post .tmvs-grid-title a:hover,.dgwork-product-grid .type-download .dgwork-grid-title a:hover,.text-desc .add_to_cart,.dgwork-product-tab ul li.dgwork-product-tab-active a, body.logged-in #site-icons a#user_account,.tvtk_price_table header',

                                  'border-color' => '.main-navigation ul li.current_page_item a,.main-navigation ul li.current-menu-item a,.main-navigation ul li.current-menu-parent a,.bullet_links a.active,.nav-filters li:hover, .nav-filters li.active,.dgwork_pagenavi span,.tmvs_pagenavi span,#edd_discounts_list li:hover,.text-desc .add_to_cart,.dgwork-product-tab ul li.dgwork-product-tab-active,#dgwork-buy .preview-demo',

                                  'border-left-color' => '.account_content input[type="text"]:focus,.account_content input[type="email"]:focus,.account_content input[type="password"]:focus,#dgw_popup .popup_content #search_product:focus',

                                  'background-color' => 'body .custom_price_table header h3,body .custom_price_table.featured header h3,body .custom_price_table.featured header h3,body .custom_price_table header .price,input[type="button"],input[type="submit"],input[type="reset"],.button,.plyr--fullscreen-enabled [data-plyr=fullscreen]:hover,#edd_discounts_list li .edd_discount_name,.bullet_links a.active,.nav-filters li:hover, .nav-filters li.active,.preview-close:hover,.dgwork_pagenavi span,.tmvs_pagenavi span,.text-desc .add_to_cart:hover,.custom_edd_button.button:hover,.edd_pagination span',
                                 ),
            ),
            array(
                'id'       => 'highlight_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Highlight Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#ff839e',
                'output'   => array('background-color'=>'.dgwork_user_nav ul li.logout a,.dgwork_user_nav ul li.register a,body .custom_price_table.featured header h3, body .custom_price_table.featured header .price,body .custom_price_table.featured footer .custom_price_table_button,.custom-edd-product-template .buy_info .edd_go_to_checkout,.tvtk_price_table.featured header,
.tvtk_price_table.featured .button',

                                    'color'=>'.edd-alert-error,#edd_profile_editor_form .error,#edd_login_form .edd-lost-password a',

                                    'border-color'=>'.edd-alert-error'
                                   )
            ),


            array(
                'id'       => 'nav_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Navigation Background Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#fff',
                'output'   => array('background-color'=>'#dgw-topbar,#dgw-topbar.sticky-nav')
            ),
            array(
                'id'       => 'nav_link_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Navigation Link Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#000',
                'output'   => array('color'=>'.main-navigation a,#site-icons a')
            ),

            array(
                'id'       => 'bottom_bg_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Bottom Widget Area Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#fff',
                'output'   => array('background-color'=>'.site-bottom')
            ),

            array(
                'id'       => 'bottom_text_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Bottom Widget Text Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#333',
                'output'   => array('color'=>'.site-bottom,.site-bottom .widget-title')
            ),

            array(
                'id'       => 'bottom_link_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Bottom Widget Link Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#222',
                'output'   => array('color'=>'.site-bottom a,.site-bottom .widget li a')
            ),

            array(
                'id'       => 'footer_bg_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Background Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#f8f8f8',
                'output'   => array('background-color'=>'.site-footer')
            ),

            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Text Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#333',
                'output'   => array('color'=>'.site-footer')
            ),

            array(
                'id'       => 'footer_link_color',
                'type'     => 'color',
                'title'    => esc_html__( 'Footer Link Color', 'dgwork' ),
                'validate' => 'color',
                'transparent' => false,
                'default'  => '#222',
                'output'   => array('color'=>'.site-footer a')
            ),
        )
    ) );

Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'dgwork' ),
        'id'               => 'design-typography',
        'icon'             => 'el el-font',
        'desc'             => esc_html__( 'Customize the typography design.', 'dgwork' ),
        'fields'           => array(
            array(
                'id'       => 'typo-body-font',
                'type'     => 'typography',
                'title'    => esc_html__( 'Page Content Font', 'dgwork' ),
                'desc' => esc_html__( 'The default page content font is Roboto', 'dgwork' ),
                'google'      => true, 
                'font-backup' => true,
                'font-weight' => false, 
                'font-style'  => false,
                'text-align'   => false,
                'font-size'   => false,
                'line-height' => false,
                'color'       => false,
                'output'      => array('font-family'=>'body,.entry-content'),
                'units'       =>'px',
                'default'  => array(
                                'font-family' => 'Roboto', 
                                'google'      => true,
                            ),
            ),

            array(
                'id'       => 'typo-heading-font',
                'type'     => 'typography',
                'title'    => esc_html__( 'Heading Font', 'dgwork' ),
                'google'      => true, 
                'font-backup' => true,
                'font-weight' => false, 
                'font-style'  => false,
                'font-size'   => false,
                'text-align'   => false,
                'line-height' => false,
                'color'       => false,
                'output'      => array('h1,h2,h3,h4,h5,h6'),
                'units'       =>'px',
                'default'  => array(
                                'font-family' => 'Roboto', 
                                'google'      => true,
                            ),
            ),

            array(
                'id'       => 'typo-menu-font',
                'type'     => 'typography',
                'title'    => esc_html__( 'Menu Font', 'dgwork' ),
                'google'      => true, 
                'font-backup' => true,
                'font-weight' => false, 
                'font-style'  => false,
                'font-size'   => false,
                'text-align'   => false,
                'line-height' => false,
                'color'       => false,
                'output'      => array('.main-navigation,.main-navigation a'),
                'units'       =>'px',
                'default'  => array(
                                'font-family' => 'Roboto', 
                                'google'      => true,
                            ),
            ),
            
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Custom Codes', 'dgwork' ),
        'id'               => 'custom-code',
        'icon'             => 'el el-css',
        'desc'             => esc_html__( 'Add your custom CSS or Javascript codes below.', 'dgwork' ),
        'fields'           => array(

            array(
                'id'       => 'custom_css',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Custom CSS', 'dgwork' ),
                'mode'     => 'css',
                'theme'    => 'chrome',
                'desc'     => esc_html__('Add custom CSS to override the original styles without &lt;style&gt; tag.','dgwork'),
                'default'  => ''
            ),

            array(
                'id'       => 'custom_javascript',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Custom Javascript', 'dgwork' ),
                'mode'     => 'javascript',
                'theme'    => 'chrome',
                'desc'     => esc_html__('Add custom javascript codes without &lt;script&gt; tag.','dgwork'),
                'default'  => '',
            ),

            array(
                'id'       => 'header_code',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Header Code', 'dgwork' ),
                'mode'     => 'html',
                'theme'    => 'chrome',
                'desc'     => esc_html__('The header code will be inserted into &lt;head&gt;...&lt;/head&gt;','dgwork'),
                'default'  => '',
            ),

            array(
                'id'       => 'footer_code',
                'type'     => 'ace_editor',
                'title'    => esc_html__( 'Footer Code', 'dgwork' ),
                'mode'     => 'html',
                'theme'    => 'chrome',
                'desc'     => esc_html__('The footer code will be inserted above &lt;/body&gt; tag.','dgwork'),
                'default'  => '',
            )
        )
    ));




    /*
     * <--- END SECTIONS
     */

    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */
    /*
    *
    * --> Action hook examples
    *
    */
    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );
    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);
    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );
    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );
    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');
    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action($options, $css, $changed_values) {
            echo '<h1>The compiler hook has run!</h1>';
             
            print_r ($options);
            print_r ($css);
            print_r ($changed_values);
        }
    }
    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;
            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }
            $return['value'] = $value;
            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }
            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }
            return $return;
        }
    }
    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }
    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_html__( 'Section via hook', 'dgwork' ),
                'desc'   => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'dgwork' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );
            return $sections;
        }
    }
    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;
            return $args;
        }
    }
    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';
            return $defaults;
        }
    }
    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );
                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }
