<?php
/** 
 * DGWork Initialize
 * @package DGWork
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$dgwork_theme 	= wp_get_theme( 'dgwork' );
$dgwork_option  = get_option('dgwork_option');

if(!class_exists('DGWork')){
	class DGWork{

		/**
		 * A reference to an instance of this class.
		 *
		 * @since 2.3.3
		 * @var   object
		 */
		private static $instance = null;

		/**
		 * Bundled Plugins.
		 *
		 * @static
		 * @access public
		 * @var array
		 */
		public static $bundled_plugins = array(
			'themevan-toolkit' => array(
				'slug'    => 'themevan-toolkit',
				'name'    => 'ThemeVan Toolkit',
				'version' => '1.4.5',
			),
			'wpbakery-page-builder' => array(
				'slug'    => 'js_composer',
				'name'    => 'WPBakery Page Builder',
				'version' => '6.0.5'
			),
			'vc_responsive_pro' => array(
				'slug'    => 'vc_responsive_pro',
				'name'    => 'Responsive PRO for WPBakery Page Builder',
				'version' => '1.2.4'
			),
			'slider_revolution' => array(
				'slug'    => 'revslider',
				'name'    => 'Slider Revolution',
				'version' => '6.1.2',
			)
		);

		/**
		 * Setup class.
		 *
		 * @since 2.14
		 */
		public function __construct() {
			add_action( 'after_setup_theme',          array( $this, 'constants' ) , 1);
			add_action( 'after_setup_theme',          array( $this, 'setup' ) );
			add_filter( 'after_setup_theme',          array( $this, 'load_files' ) );
			add_filter( 'after_setup_theme',          array( $this, 'check_update' ) );
			add_action( 'widgets_init',               array( $this, 'widgets_init' ) );
			add_action( 'wp_enqueue_scripts',         array( $this, 'scripts' ), 1);
			add_action( 'wp_enqueue_scripts',         array( $this, 'child_scripts' ), 30 ); 
			add_action( 'admin_enqueue_scripts',      array( $this, 'admin_scripts' ), 30 ); 
			add_action( 'vc_before_init', 			  array( $this, 'set_vc_as_theme' ) );
			add_filter( 'pt-ocdi/import_files', 	  array( $this,'import_files') );
			add_action( 'pt-ocdi/after_import',       array( $this,'after_import') );
			add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
			add_action( 'after_switch_theme', 		  array( $this, 'version_check' ) );
		}

		/**
		 * Define Constants for the theme.
		 * @since 2.3.3
		 */
		public function constants(){
			global $dgwork_option;
			define('DGWORK_THEME_URI', get_template_directory_uri());
			define('DGWORK_THEME_DIR', get_template_directory());
			define('DGWORK_INC_URI', DGWORK_THEME_URI.'/inc/');
			define('DGWORK_INC_DIR', DGWORK_THEME_DIR.'/inc/');
			define('DGWORK_DEBUG',   $dgwork_option['minify']);
			define('EDD_SLUG', esc_html($dgwork_option['edd_slug']));
			define('THEMEVAN_API',   'https://www.themevan.com/api/');
			define('DGWORK_ITEM_ID', intval('18105506')); // Don't change it, otherwise, your purchase code can't be verified.
		}

		/**
		 * Gets the bundled plugins.
		 *
		 * @static
		 * @access public
		 * @since 2.3
		 * @return array Array of bundled plugins.
		 */
		public static function get_bundled_plugins() {
			return self::$bundled_plugins;
		}


		/**
		 * Sets up theme defaults and registers support for various WordPress features.
		 *
		 * Note that this function is hooked into the after_setup_theme hook, which
		 * runs before the init hook. The init hook is too late for some features, such
		 * as indicating support for post thumbnails.
		 */
		public function setup(){

			add_editor_style('editor-style.css');
			add_theme_support( 'automatic-feed-links' );
			
		    /*Add Title*/
			add_theme_support( 'title-tag' );
			
			/*Declare WooCommerce support*/
			add_theme_support( 'woocommerce');
			add_theme_support( 'wc-product-gallery-zoom' );
			add_theme_support( 'wc-product-gallery-lightbox' );
			add_theme_support( 'wc-product-gallery-slider' );

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comments',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			) );
			
			/*
		 	 * Make theme available for translation.
			 * Translations can be filed in the /languages/ directory.
			 * If you're building a theme based on dgwork, use a find and replace
			 * to change 'dgwork' to the name of your theme in all the template files.
			 */
			load_theme_textdomain( 'dgwork', get_template_directory() . '/languages' );
			$locale = get_locale(); 
			$locale_file = get_template_directory()."/languages/$locale.php"; 
			if ( is_readable($locale_file) ) require_once($locale_file);
			
			/*Add diffierent size for post thumbnails*/
			add_theme_support('post-thumbnails');

			/*Init nav menus*/
			register_nav_menus( array(
				'primary' => esc_html__( 'Primary Menu', 'dgwork' ),
				'mobile' => esc_html__( 'Mobile Menu', 'dgwork' ),
			) );

			/*Change excerpt more string*/
			function dgwork_excerpt_more( $more ) {
				return '...';
			}
			add_filter( 'excerpt_more', 'dgwork_excerpt_more' );

			// Set up the WordPress core custom header feature.
			add_theme_support( 'custom-header', apply_filters( 'dgwork_custom_header_args', array(
				'default-image'          => '',
				'width'                  => 1200,
				'height'                 => 500,
				'flex-height'            => true,
				'default-text-color' 	 => '',
			) ) );

			// Custom LOGO
			add_theme_support( 'custom-logo', array(
				'height'      => 60,
				'width'       => 280,
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
			) );

		    add_action( 'customize_register', 'dgwork_remove_customize_option' );
			function dgwork_remove_customize_option($wp_customize){
			    $wp_customize->remove_control('header_textcolor');
		    }

		    /* Remove admin bar for subscribers */
		    if(function_exists('tmvs_hide_adminbar_for_subscribers')){
				tmvs_hide_adminbar_for_subscribers();
			}

			$GLOBALS['content_width'] = apply_filters( 'dgwork_content_width', 1000 );

			// Gutenberg Support
			add_theme_support( 'align-wide' );
			add_theme_support(
			    'gutenberg',
			    array( 'wide-images' => true )
			);
		}

		/**
		 * Register widget area.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
		 */
		public function widgets_init() {
			register_sidebar( array(
				'name'          => esc_html__( 'Blog Sidebar', 'dgwork' ),
				'id'            => 'sidebar',
				'description'   => esc_html__('This sidebar will included in the category and single post page.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			) );
			
			register_sidebar( array(
				'name'          => esc_html__( 'Page Sidebar', 'dgwork' ),
				'id'            => 'sidebar-page',
				'description'   => esc_html__('This sidebar will included in the default page template.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			) );
			
			if ( class_exists( 'Easy_Digital_Downloads' ) ){
			 register_sidebar( array(
				'name'          => esc_html__( 'Shop Sidebar', 'dgwork' ),
				'id'            => 'sidebar-shop',
				'description'   => esc_html__('This sidebar will included in the product category pages.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			 ) );
			 
			 register_sidebar( array(
				'name'          => esc_html__( 'Product Common Sidebar', 'dgwork' ),
				'id'            => 'sidebar-download',
				'description'   => esc_html__('This sidebar will included in the single product pages.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			 ) );
			}

			register_sidebar( array(
				'name'          => esc_html__( 'Custom Footer', 'dgwork' ),
				'id'            => 'custom-footer',
				'description'   => esc_html__('This widget area is placed at top of the bottom widgets section.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
		    ) );
			
			register_sidebar( array(
				'name'          => esc_html__( 'Bottom Widget 1', 'dgwork' ),
				'id'            => 'bottom-widget-1',
				'description'   => esc_html__('This widget area is placed at the left of bottom area.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
		    ) );
		    
		    register_sidebar( array(
				'name'          => esc_html__( 'Bottom Widget 2', 'dgwork' ),
				'id'            => 'bottom-widget-2',
				'description'   => esc_html__('This widget area is placed at the second left of bottom area.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
		    ) );
		    
		    register_sidebar( array(
				'name'          => esc_html__( 'Bottom Widget 3', 'dgwork' ),
				'id'            => 'bottom-widget-3',
				'description'   => esc_html__('This widget area is placed at the middle of bottom area.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
		    ) );

		    register_sidebar( array(
				'name'          => esc_html__( 'Bottom Widget 4', 'dgwork' ),
				'id'            => 'bottom-widget-4',
				'description'   => esc_html__('This widget area is placed at the right of bottom area.','dgwork'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
		    ) );
		}

		/**
		 * Enqueue scripts and styles.
		 *
		 * @since 2.14
		 */
		public function scripts() {
			global $dgwork_option;
			
			$sticky_top = 1;
			if(isset($dgwork_option['sticky_top']) && $dgwork_option['sticky_top'] == 0){
				$sticky_top = 0;
			}else{
				$sticky_top = 1;
			}

		    wp_enqueue_style( 'dgwork-style', get_stylesheet_uri(), '', null );
			wp_enqueue_style( 'font-awesome', DGWORK_INC_URI .'assets/css/font-awesome/css/font-awesome.min.css', '', null );
			wp_enqueue_script( 'jquery-easing', DGWORK_INC_URI . 'assets/js/jquery.easing.min.js', array('jquery') );
			wp_enqueue_script( 'masonry' );
			wp_enqueue_script( 'hoverIntent' );
			wp_enqueue_script( 'imagesLoaded' );

			if(DGWORK_DEBUG==0){
			    /* ================================
			    * Enqueue CSS files
			    * ===============================*/
			    wp_enqueue_style( 'dgwork-grid', DGWORK_INC_URI .'assets/css/grid.css', array( 'dgwork-style' ), null );
			    wp_enqueue_style( 'dgwork-main', get_template_directory_uri() .'/assets/css/main.css', array( 'dgwork-style' ), null );
				wp_enqueue_script( 'dgwork-plugins', DGWORK_INC_URI . 'assets/js/plugins.js', array('jquery'), null, true );
				wp_enqueue_script( 'dgwork', get_template_directory_uri() . '/assets/js/theme.js', array('jquery'),null, true );

			    if ( class_exists( 'Easy_Digital_Downloads' ) ){
					wp_enqueue_style( 'audio-player',DGWORK_INC_URI .'assets/js/plyr/plyr.css', '', null );
					wp_enqueue_style( 'swiper', DGWORK_INC_URI .'assets/js/swiper/swiper.min.css', '', null );
					wp_enqueue_style( 'dgwork-edd', get_template_directory_uri() .'/assets/css/dgwork.css', '', null );
					wp_enqueue_script( 'jquery-swiper', DGWORK_INC_URI . 'assets/js/swiper/swiper.jquery.min.js', array('jquery'), null, true );
					wp_enqueue_script( 'dgwork-AudioPlayer', DGWORK_INC_URI . 'assets/js/plyr/plyr.js', array('jquery'), null, true );
					wp_enqueue_script( 'dgwork-edd', get_template_directory_uri() .'/assets/js/dgwork_edd.js', array('jquery'), null, true );
				}

				if ( class_exists( 'Affiliate_WP' ) ){
					wp_enqueue_style( 'dgwork-affiliateWP', get_template_directory_uri() .'/assets/css/affiliatewp.css', '', null );
				}
				if ( class_exists( 'EDD_Front_End_Submissions' ) ){
					wp_enqueue_style( 'dgwork-edd-fes', get_template_directory_uri() .'/assets/css/edd-fes.css', '', null );
				}
				if ( class_exists( 'EDD_Wish_Lists' ) ){
					wp_enqueue_style( 'dgwork-edd-wishlists', get_template_directory_uri() .'/assets/css/edd-wish-lists.css', '', null );
				}

	        }else{
				wp_enqueue_style( 'dgwork', get_template_directory_uri() .'/build/site.min.css', array( 'dgwork-style' ), null );
				wp_enqueue_script( 'dgwork', get_template_directory_uri() . '/build/site.min.js', array('jquery'),null, true );
		    }
;
		     /* DGWork Data */
			 wp_localize_script( 'dgwork', 'dgwork_data', array(
			   		'sticky_top' => $sticky_top,
			   		'save_text'  => esc_html__('Saving','dgwork'),
			   		'save_button_text' => esc_html__('Save Changes', 'dgwork'),
			   		'register_text' => esc_html__('Register','dgwork'),
			   		'menu_select_text' => esc_html__('Please Select', 'dgwork'),
			   		'psw_error'	=> esc_html__('The passwords you have entered do not match.', 'dgwork'),
			   		'profile_edit_success' => esc_html__('Your profile was sucessfully changed.', 'dgwork'),
			   		'currency' => function_exists('edd_currency_symbol') ? edd_currency_symbol() : '$'
			 ));

		   /* ===============
			* Fonts
			* ==============*/
			 $fonts_url = '';
		     $roboto_slab = _x( 'on', 'Roboto Slab font: on or off', 'dgwork' );
		     $roboto = _x( 'on', 'Roboto: on or off', 'dgwork' );
		     $Lato = _x( 'on', 'Lato: on or off', 'dgwork' );
		    
		     if ('off' !== $roboto_slab || 'off' !== $roboto || 'off' !== $Lato) {
			    $font_families = array();
			 
			    if ( 'off' !== $roboto ) {
			        $font_families[] = 'Roboto:100,300,400,400italic,500,500italic,700,700italic,900,900italic';
			    }
			    
			    if ( 'off' !== $roboto_slab ) {
			        $font_families[] = 'Roboto Slab:300,400,700';
			    }
			    
			    if ( 'off' !== $Lato ) {
			        $font_families[] = 'Lato:100,300,400,700 900';
			    }
			    
			    $query_args = array(
		            'family' => urlencode( implode( '|', $font_families ) ),
		            'subset' => urlencode( 'latin,latin-ext,vietnamese,cyrillic-ext,cyrillic,greek,greek-ext' ),
		        );
		 
		        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
			}
			wp_enqueue_style( 'dgwork-default-fonts', esc_url_raw($fonts_url), array(), null );
		    
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}
		}

		/**
		 * Enqueue child theme stylesheet.
		 * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
		 * primary css and the separate WooCommerce css.
		 *
		 * @since  2.14
		 */
		public function child_scripts() {
			if ( is_child_theme() ) {
				wp_enqueue_style( 'dgwork-child-style', get_stylesheet_uri(), '' );
			}
		}

		/**
		 * Load Scripts in WP admin	
		 */
		public function admin_scripts(){
			wp_enqueue_style( 'farbtastic' );
			wp_enqueue_script( 'farbtastic' );
			wp_enqueue_style("dgwork-admin", DGWORK_INC_URI."assets/css/admin.css", false, "1.0", "all");
			wp_enqueue_script("admin_script", DGWORK_INC_URI."assets/js/admin_script.js",array('jquery'));
		}

		/* Load Framework
		 * Include the framework function files.
		 */
		public function load_files(){

			require DGWORK_INC_DIR.'class.mobile.php';

			/**
			 * Function liburary.
			 */
			require DGWORK_INC_DIR.'functions/lib.php';
			
			/**
			 * Custom Widget.
			 */
			require DGWORK_INC_DIR.'widgets/wdiget-recent-posts.php';
			require DGWORK_INC_DIR.'widgets/widget-recent-comments.php';
				
			/**
			 * Custom template tags for this theme.
			 */
			require DGWORK_INC_DIR.'functions/template-tags.php';
			
			/**
			 * Custom functions that act independently of the theme templates.
			 */
			require DGWORK_INC_DIR.'functions/extras.php';

			/**
			 * Force to change Elementor default settings
			 */
			if ( class_exists( '\Elementor\Plugin') ){
				require DGWORK_INC_DIR.'functions/elementor.php';
			}


			/**
			 * Hooks
			 */
			require DGWORK_INC_DIR.'functions/hooks.php';
			
			/**
			 * If Easy Digital Downloads is actived, load custom woocommerce template tags for this theme.
			 */
			if ( class_exists( 'Easy_Digital_Downloads' ) ){
				require DGWORK_INC_DIR.'edd/template-tags.php';
				require DGWORK_INC_DIR.'edd/taxonomy-metabox.php';
				require DGWORK_INC_DIR.'edd/hooks.php';
				require DGWORK_INC_DIR.'edd/extras.php';
			}

		    /**
			 * Visual Composer Templates
			 */
		    if ( function_exists( 'vc_map')){
		       require DGWORK_INC_DIR.'functions/vc-predefined-templates.php';
		    }

		    /**
			 * Function liburary.
			 */
			require DGWORK_INC_DIR.'mega-menu/mega-menu.php';
			
			/**
			 * Plugins
			 */
			require DGWORK_INC_DIR.'admin/class.admin.php';
			require DGWORK_INC_DIR.'admin/plugins.php';
		    
		    /**
			 * load custom metabox
			 */
		    require DGWORK_INC_DIR.'admin/metabox.php';
		    require DGWORK_INC_DIR.'admin/category-metabox.php';
			
			/**
		     * Admin
			 */
		    require DGWORK_INC_DIR.'admin/options-init.php';
		}

		/**
		 * Set VC as theme.
		 */
		public function set_vc_as_theme() {
		    vc_set_as_theme();
		}

		/**
		 * Check Theme Updates
		 */
		public function check_update(){
			if( DGWorkAdmin::check_license()) {
		      require_once(DGWORK_INC_DIR.'admin/theme-update-checker.php');
			  $theme_update_checker = new ThemeUpdateChecker(
			    'dgwork',
			    'https://www.themevan.com/update-server/?action=get_metadata&slug=dgwork'
			  );
		    }
		}

		
	    /* Import Demo */
		public function import_files() {
		    return array(
		        array(
		            'import_file_name'           => 'Demo By Elementor',
		            'categories'                   => array( 'Elementor' ),
		            'import_file_url'            => 'https://dgwork.co/data/default-elementor/content.xml',
		            'import_preview_image_url'   => 'https://dgwork.co/data/default-elementor/screenshot.jpg',
		            'import_widget_file_url'     => 'https://dgwork.co/data/default-elementor/widgets.json',
           			'import_customizer_file_url' => 'https://dgwork.co/data/default-elementor/customizer.dat',
		            'import_redux'           => array(
		                    array(
		                        'file_url'   => 'https://dgwork.co/data/default-elementor/options.json',
		                        'option_name' => 'dgwork_option',
		                    ),
		                ),
		        ),

		        array(
		            'import_file_name'           => 'Demo By WPBakery Page Builder',
		            'categories'                   => array( 'WPBakery Page Builder' ),
		            'import_file_url'            => 'https://dgwork.co/data/default/content.xml',
		            'import_preview_image_url'   => 'https://dgwork.co/data/default/screenshot.jpg',
		            'import_widget_file_url'     => 'https://dgwork.co/data/default/widgets.json',
           			'import_customizer_file_url' => 'https://dgwork.co/data/default/customizer.dat',
		            'import_redux'           => array(
		                    array(
		                        'file_url'   => 'https://dgwork.co/data/default/options.json',
		                        'option_name' => 'dgwork_option',
		                    ),
		                ),
		        ),
		    );
	    }

	    /* Before Import demo */
	    public function before_import( $selected_import ){
	    	if( $selected_import['import_file_name'] == 'Demo By WPBakery Page Builder' ){
	    		if( ! class_exists( 'vc_map' ) ){
	    			echo '<script>alert('.esc_html__('Please install and activate WPBakery Page Builder before you import this demo.', 'dgwork').');</script>';
	    			return false;
	    		}
	    	}

	    	if( $selected_import == 'Demo By Elementor' ){
	    		if( ! class_exists( 'vc_map' ) ){
	    			echo '<script>alert('.esc_html__('Please install and activate Elementor Page Builder before you import this demo.', 'dgwork').');</script>';
	    			return false;
	    		}
	    	}
	    }
	    
	    /* After Import demo */
	    public function after_import( $selected_import ) {
		    //Set Menu
		    $top_menu = get_term_by('name', 'Top Menu', 'nav_menu');
		    set_theme_mod( 'nav_menu_locations' , 
		        array( 
		              'primary' => $top_menu->term_id, 
		              'mobile' =>  $top_menu->term_id 
		             ) 
		    );

		    //Set Front page
		    $page = get_page_by_title( 'Home');
		    if ( isset( $page->ID ) ) {
		        update_option( 'page_on_front', $page->ID );
		        update_option( 'show_on_front', 'page' );
		    }

		    $slider_array = array(
		          DGWORK_INC_DIR."demo/default/home-slider-1.zip",
                  DGWORK_INC_DIR."demo/default/home_slider_2.zip"
		    );

		    if ( class_exists( 'RevSlider' ) ) {
		      $slider = new RevSlider();
		       
		      foreach($slider_array as $filepath){
		       $slider->importSliderFromPost(true,true,$filepath);  
		      }
		       
		      echo ' Slider processed';
		    }
		}


		/**
		 * Init version
		 * @since 1.0.0
		 */
		public function version_check(){
			global $dgwork_theme;

			$init_version = get_option( 'dgwork_init_version' );
			if( ! isset( $init_version ) || $init_version == '' || empty( $init_version ) ) {
				add_option( 'dgwork_init_version',  $dgwork_theme->get( 'Version' ) );
			}
		}

		

		/**
		 * Returns the instance.
		 *
		 * @since  2.3.3
		 * @return object
		 */
		public static function get_instance() {

			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}

			return self::$instance;
		}
	}
}

function DGWork() {
   	return DGWork::get_instance();
}
function dgwork_user_agent() {
    return 'dgwork-user-agent';
}

return DGWork();
