<?php
/**
 * Custom functions that act independently of the EDD default templates.
 * Eventually, some of the functionality here could be replaced by core features. 
 * @package DGWork
 */
 
/* Remove the EDD default style */
remove_action( 'wp_enqueue_scripts', 'edd_register_styles');

/* remove the standard button that shows after the download's content */
remove_action( 'edd_after_download_content', 'edd_append_purchase_link' );

/* Customize the product category slug for EDD plugin */
if ( ! function_exists( 'dgwork_customize_category_slug' ) ) :
function dgwork_customize_category_slug( $category_labels ) {
	global $dgwork_option;
	$slug = defined( 'EDD_SLUG' ) ? EDD_SLUG : 'product';

	$edd_category_slug = esc_html('products');
	if(isset($dgwork_option['edd_category_slug'])){
		$edd_category_slug = esc_html($dgwork_option['edd_category_slug']);
	}
	$category_labels['rewrite'] = array('slug' =>$edd_category_slug, 'with_front' => false, 'hierarchical' => true );
	return $category_labels;
}
add_filter( 'edd_download_category_args', 'dgwork_customize_category_slug');
endif;

/* Reset some labels */
if ( ! function_exists( 'dgwork_set_download_labels' ) ) :
function dgwork_set_download_labels($labels) {
	$labels = array(
		'name' => _x('Products', 'post type general name', 'dgwork'),
		'singular_name' => _x('Product', 'post type singular name', 'dgwork'),
		'add_new' => __('Add New', 'dgwork'),
		'add_new_item' => __('Add New Product', 'dgwork'),
		'edit_item' => __('Edit Product', 'dgwork'),
		'new_item' => __('New Product', 'dgwork'),
		'all_items' => __('All Products', 'dgwork'),
		'view_item' => __('View Product', 'dgwork'),
		'search_items' => __('Search Products', 'dgwork'),
		'not_found' =>  __('No Products found', 'dgwork'),
		'not_found_in_trash' => __('No Products found in Trash', 'dgwork'), 
		'parent_item_colon' => '',
		'menu_name' => __('Products', 'dgwork')
	);
	return $labels;
}
add_filter('edd_download_labels', 'dgwork_set_download_labels');
endif;


if ( ! function_exists( 'dgwork_current_item' ) ) :
function dgwork_current_item($label,$target){
  $class='';
  if($label==$target){
    $class=' class=current';
  }
  echo esc_html($class);
}
endif;

/* Add new currencies */
if ( ! function_exists( 'dgwork_extra_edd_currencies' ) ) :
function dgwork_extra_edd_currencies( $currencies ) {
	$currencies['₩'] = __('Korean Won (₩)', 'dgwork');
	$currencies['¥'] = __('Chinese Yuan (¥)', 'dgwork');
	return $currencies;
}
endif;
add_filter('edd_currencies', 'dgwork_extra_edd_currencies');


/**
 * Custom image size for EDD Related Downloads.
 */
if ( ! function_exists( 'dgwork_isa_related_downloads_image_size' ) ) :
function dgwork_isa_related_downloads_image_size( $post ) {
    return 'large';
}
endif;
add_filter( 'edd_related_downloads_image_size', 'dgwork_isa_related_downloads_image_size' );


if( ! function_exists('dgwork_edd_download_supports') ):
function dgwork_edd_download_supports( $supports ) {
 
	// add support for comments
	$supports[] = 'comments';
 
	// pass it back to EDD
	return $supports;	
 
} 
endif;
add_filter('edd_download_supports', 'dgwork_edd_download_supports');