<?php
/**
 * Mega Menu Settings
 * Tuts: https://www.wpexplorer.com/adding-custom-attributes-to-wordpress-menus/
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class dgwork_mega_menu {

    /*--------------------------------------------*
     * Constructor
     *--------------------------------------------*/

    /**
     * Initializes the plugin by setting localization, filters, and administration functions.
     */
    function __construct() {
        
        // add custom menu fields to menu
        add_filter( 'wp_setup_nav_menu_item', array( $this, 'dgwork_add_custom_nav_fields' ) );

        // save menu custom fields
        add_action( 'wp_update_nav_menu_item', array( $this, 'dgwork_update_custom_nav_fields'), 10, 3 );
        
        // edit menu walker
        add_filter( 'wp_edit_nav_menu_walker', array( $this, 'dgwork_edit_walker'), 10, 2 );

    } // end constructor
    
    
    /**
     * Add custom fields to $item nav object
     * in order to be used in custom Walker
     *
     * @access      public
     * @since       1.0 
     * @return      void
    */
    function dgwork_add_custom_nav_fields( $menu_item ) {
    
        $menu_item->megamenu = get_post_meta( $menu_item->ID, '_menu_item_megamenu', true );
        return $menu_item;
        
    }
    
    /**
     * Save menu custom fields
     *
     * @access      public
     * @since       1.0 
     * @return      void
    */
    function dgwork_update_custom_nav_fields( $menu_id, $menu_item_db_id, $args ) {
    
        // Check if element is properly sent
        if ( is_array( $_REQUEST['menu-item-megamenu']) ) {
            $megamenu_value = $_REQUEST['menu-item-megamenu'][$menu_item_db_id];
            update_post_meta( $menu_item_db_id, '_menu_item_megamenu', $megamenu_value );
        }
        
    }
    
    /**
     * Define new Walker edit
     *
     * @access      public
     * @since       1.0 
     * @return      void
    */
    function dgwork_edit_walker($walker,$menu_id) {
    
        return 'Walker_Nav_Menu_Edit_Custom';
        
    }

}

// instantiate plugin's class
$GLOBALS['dgwork_mega_menu'] = new dgwork_mega_menu();


include_once( 'edit_custom_walker.php' );
include_once( 'custom_walker.php' );